    
.. rst-class:: image-no-text-wrap
.. figure:: _static/coronalab.svg
    :align: left
    :width: 250px

|
=================================================
CoronaLab: Creating Synthetic Corona Observations
=================================================

.. |clearfloat|  raw:: html

    <div class="clearer"></div>

|clearfloat|

    
This package allows the user to create synthetic data products from a 3D model of a stellar coronal magnetic field. Extrapolating the coronal magnetic field and tracing field lines is not included so users can choose whatever method they want (e.g. sunkit-magex).


.. grid:: 2
   
    .. grid-item-card::
        :img-top: _static/installation.svg
        :text-align: center

        Getting Started
        ^^^^^^^^^^^^^^^

        New to Coronalab? Click here for installation
        instructions and basic usage.

        +++
    
        .. button-ref:: intro
                :expand:
                :color: primary
                :click-parent:

                Introductory Guide

    .. grid-item-card::
        :img-top: _static/documentation.svg
        :text-align: center

        Documentation
        ^^^^^^^^^^^^^

        Click here specific CoronaLab documentation.

        +++
    
        .. button-ref:: api
                :expand:
                :color: primary
                :click-parent:

                Documentation

    .. grid-item-card::
        :img-top: _static/github.svg
        :text-align: center

        GitHub
        ^^^^^^

        Click here to visit the project on GitHub.

        +++
    
        .. button-link:: https://github.com/St-andrews-cool-stars/CoronaLab
                :expand:
                :color: primary
                :click-parent:

                Github Repo


    .. grid-item-card::
        :img-top: _static/license.svg
        :text-align: center

        License
        ^^^^^^^

        CoronaLab is licensed under a 3-clause BSD style license.
    
        +++
    
        .. button-ref:: LICENSE
                :expand:
                :color: primary
                :click-parent:

                License

    
